@@ -66,7 +66,7 @@ Example_StockBrowser::Example_StockBrowser()
   m_Frame("Selected Item"),
   m_VBox(false, 8),
   m_HBox(false, 8),
-  m_Alignment(Gtk::ALIGN_CENTER, Gtk::ALIGN_TOP, 0.0, 0.0)
+  m_Alignment(Gtk::ALIGN_CENTER, Gtk::ALIGN_START, 0.0, 0.0)
 {
   set_title("Stock Icons and Items");
   set_default_size(-1, 500);
